import Vue from 'vue'

window.formatByteSize=function(value){
    if(value==null){
        return "";
    }
    if(value<1024){
        return value+"B";
    }
    if(value<1024*1024){
        return (parseFloat(value/1024)).toFixed(2)+"KB";
    }
    if(value<1024*1024*1024){
        return (parseFloat(value/1024/1024)).toFixed(2)+"MB";
    }
    var q=parseFloat(value/(1024*1024*1024));
    return q.toFixed(2)+"GB";
};
//公共函数
window.formatNumber=function(n){
    n = n.toString();
    return n[1] ? n : '0' + n
};
window.formatTime=function(t){
    if(t==null){
        return "-";
    }
    var date=new Date(t);
    var hour = date.getHours();
    var minute = date.getMinutes();
    return [hour, minute].map(formatNumber).join(':')
};
window.formatDatetime=function(t){
    if(t==null){
        return "-";
    }
    var date=new Date(t);
    var year = date.getFullYear()>2000?date.getFullYear()-2000:date.getFullYear();
    var month = date.getMonth() + 1;
    var day = date.getDate();
    var hour = date.getHours();
    var minute = date.getMinutes();
    var second = date.getSeconds();
    return [year, month, day].map(formatNumber).join('-') + ' ' + [hour, minute].map(formatNumber).join(':')
};
window.formatDate=function(t){
    if(t==null){
        return "-";
    }
    var date=new Date(t);
    var year = date.getFullYear()>2000?date.getFullYear()-2000:date.getFullYear();
    var month = date.getMonth() + 1;
    var day = date.getDate();
    return [year, month, day].map(formatNumber).join('-');
};
//
//表单验证
window.validater={
    required:{required:true,message:"必选项"},
    rangeDate:{type:'array',length:2,required:true,message:"必选项"},
    length:{type: 'string', min: 4,max:50,message:"长度为4-50个字"},
    lengthShort:{type: 'string', min: 4,max:20,message:"长度为4-20个字"},
    lengthName:{type: 'string', min: 2,max:10,message:"长度为2-10个字"},
    lengthMax:{type: 'string', max:50,message:"长度最大50个字"},
    intValue:{type: 'integer',min:1,message:"必须为正整数"}   ,
    mobile:{type: 'string',length:11,message:"手机号格式错误"},
    email:{type: 'email',message:"邮箱格式错误"},

};

//
Vue.filter('fmtPercent', function (v) {
    return parseFloat(v.toFixed(2));
})
Vue.filter('fmtMoney', function (v) {
    var v=Number(v)/100;
    return parseFloat(v.toFixed(2));
})
Vue.filter('fmtDateTime', function (v) {
    return formatDatetime(v);
})
Vue.filter('fmtDate', function (v) {
    return formatDate(v);
})
Vue.filter('fmtBool', function (t) {
    return t==true?"是":"否"
})
Vue.filter('imgurl', function (t) {
    if(t==null||t==""){
        return "./image/common/placeholder.png";
    }
    return app.serverAddr+"/p/file/get_file/"+t;
})
Vue.filter('userimgurl', function (t) {
    if(t==null||t==""){
        return "./image/common/account-placeholder.png";
    }
    return app.serverAddr+"/p/file/get_file/"+t;
})
Vue.filter('dataDict', function (value,type) {
    if(value==null){
        return "";
    }
    return app.dataDictValue(type,value)
})
Vue.filter('bytesSize', function (value) {
    return formatByteSize(value);
})
//
Vue.directive('focus', {
  inserted: function (el) {
    el.focus()
  }
})
//
window.componentMixin = {
	data(){
		return {
            title:"undefined",
            args:{},
            showDialog: false,
            isPageSelectAll:false,
			pageQuery:{
				pageIndex:1,
				pageSize:10,
				totalCount:0,
            },
            tableData:[],
            pageQuery:{
				pageIndex:1,
				pageSize:10,
				totalCount:0,
			},
		}
	},
	mounted(){
        app.onMessage('AppEvent',this.receiveMessage)
	},
	beforeDestroy() {
		this.pageDestroy();
    },
    watch:{
        showDialog(val){
            if(val==false){
                this.$el.remove();
                this.$destroy();
            }
        },
        isPageSelectAll(val){
            this.tableData.map((item)=>{
              item.isSelected=val;
            })
        }
    },
	methods: {
		pageDestroy(){
			app.offMessage('AppEvent',this.receiveMessage)
		},
		loadQueryData:function(){
            if(this.saveQueryDataKey!=null){
                var obj=window.localStorage[this.saveQueryDataKey];
                if(obj){
                    this.queryItem=JSON.parse(obj);
                }
                var tq=window.localStorage[this.saveQueryDataKey+"-tablequery"];
                if(tq){
                    this.pageQuery=JSON.parse(tq);
                }
            }
	    },    
        queryList(actionId,resetPage,callback){
	    	if(this.saveQueryDataKey!=null){
	    		window.localStorage[this.saveQueryDataKey]=JSON.stringify(this.queryItem);
	            window.localStorage[this.saveQueryDataKey+"-tablequery"]=JSON.stringify(this.pageQuery);
	        }
            if(resetPage){
                this.pageQuery.pageIndex=1;
            }
            var queryObj={};
       
            queryObj["pageIndex"]=this.pageQuery["pageIndex"];
            queryObj["pageSize"]=this.pageQuery["pageSize"];
            
            if(this.queryItem){
                for(var k in this.queryItem){
                    queryObj[k]=this.queryItem[k]
                }
            }
            var queryArray=[];
            queryArray.push(app.token);
            queryArray.push(queryObj);   
            this.isPageSelectAll=false; 
            app.invoke(actionId,queryArray,(obj)=>{
                this.tableData=obj.list;
                this.pageQuery.totalCount=obj.count;
                if(callback){
                    callback(obj.list);
                }
            })
        },
		receiveMessage(t){
			if(this.pageMessage){
				this.pageMessage(t.type,t.content);
			}
        },
        hasPermission(name){
            return app.hasPermission(name);
        },
        hasPermissions(name){
            return app.hasPermissions(name);
        },
        isCreater(obj){
            return obj.createUserId==app.userId;
        },
        isOwner(obj){
            return obj.ownerUserId==app.userId;
        },
        stopDialogButtonLoading(){
            this.$refs["dialog"].buttonLoading=false;
        }
	}
}

