import Vue from 'vue'
//
window.frameMixin = {
	data: {
		debug: true,
		version: "1.0",
		name:"AdminSystem",
		serverAddr: "",
		loadingDialog:null,
		dataDicts:[],
		permissions:[],
	},
	//
	methods: {
		dataDictValue(type,value){
			var s=this.dataDicts[type];
            if(s){
                for(var i=0;i<s.length;i++){
                    if(s[i].value==value){
                        return s[i].name;
                    }
                }
			}
			console.warn('dataDict not found',type,value);
            return "";
		},
		hasPermissions(array){
			var result=false;
			for(var i=0;i<array.length;i++){
				result=this.hasPermission(array[i]);
				if(result){
					return true;
				}
			}
			return result;
		},
		hasPermission(name){
			for(var i=0;i<app.permissions.length;i++){
				if(this.permissions[i]==name){
					return true;
				}
			}
			return false;	
		},
		toast (obj) {
			this.$Message.info({
				content:obj,
				duration: 2
			});
		},
		info(message){
			this.$Modal.info({
				title: "提示",
				content: message
			});
		},
		error(message){
			this.$Modal.error({
				title: "错误",
				content: message
			});
		},
		//
		hideLoading () {
			if(this.loadingDialog){
				this.loadingDialog.showDialog=false;
				this.loadingDialog=null;
			}
		},
		//
		showLoading (message) {
			if(this.loadingDialog){
				this.loadingDialog.showDialog=false;
				this.loadingDialog=null;
			}
			this.loadingDialog=this.showDialog(window["LoadingDialog"],{
				message:message
			})
		},
		//----------------------------------------------------------------------
		confirm (message,callback) {
			this.showDialog(window["ConfirmDialog"],{
				message:message,
				callback:callback
			})
		},
		//
		loadPage (url, args) {
			this.$router.push({ path: url, query: args })
		},
		showDialog (objName,args) {
			let dialogClass = objName;
			var dialogComp = new dialogClass().$mount()
			document.body.appendChild(dialogComp.$el)
			dialogComp.showDialog = true
			if(args){
				dialogComp.args=args;
			}
			if(dialogComp.pageLoad){
				dialogComp.pageLoad();
			}
			return dialogComp;
		},
		loadComponent(name,args,mountPoint){
			var compDefine=window[name];
			if(compDefine==null){
				console.log("can not find "+name); 
				return;
			}
			let compClass = compDefine
			var comp = new compClass().$mount(mountPoint)
			if(args){
				comp.args=args;
			}else{
				comp.args={};
			}
			console.log("load component",name,args)
			if(comp.pageLoad){
                comp.pageLoad();
			}
			return comp;
		},
		//----------------------------------------------------------------------
		postMessage (type, content) {
			this.$emit("AppEvent",{
				type:type,
				content:content
			});
		},
		onMessage(type,func){
			this.$on("AppEvent",func)
		},
		offMessage(type,func){
			this.$off("AppEvent",func)
		},
		//----------------------------------------------------------------------
		//Underscore.js 
		throttle (func, wait, options) {
			var context, args, result;
			var timeout = null;
			var previous = 0;
			if (!options) options = {};
			var later = function () {
				previous = options.leading === false ? 0 : _.now();
				timeout = null;
				result = func.apply(context, args);
				if (!timeout) context = args = null;
			};
			return function () {
				var now = _.now();
				if (!previous && options.leading === false) previous = now;
				var remaining = wait - (now - previous);
				context = this;
				args = arguments;
				if (remaining <= 0 || remaining > wait) {
					clearTimeout(timeout);
					timeout = null;
					previous = now;
					result = func.apply(context, args);
					if (!timeout) context = args = null;
				} else if (!timeout && options.trailing !== false) {
					timeout = setTimeout(later, remaining);
				}
				return result;
			};
		},
		//
		debounce (func, wait, immediate) {
			var timeout, args, context, timestamp, result;
			var later = function () {
				var last = _.now() - timestamp;
				if (last < wait && last > 0) {
					timeout = setTimeout(later, wait - last);
				} else {
					timeout = null;
					if (!immediate) {
						result = func.apply(context, args);
						if (!timeout) context = args = null;
					}
				}
			};

			return function () {
				context = this;
				args = arguments;
				timestamp = _.now();
				var callNow = immediate && !timeout;
				if (!timeout) timeout = setTimeout(later, wait);
				if (callNow) {
					result = func.apply(context, args);
					context = args = null;
				}
				return result;
			};
		},
		setCookie (name, value, expireMinutes) {
			var exdate = new Date(new Date().getTime() + expireMinutes * 60 * 1000)
			document.cookie = name + "=" + escape(value) + ";expires=" + exdate.toGMTString();
		},
		//
		getCookie (name) {
			var arr, reg = new RegExp("(^| )" + name + "=([^;]*)(;|$)");
			if (arr = document.cookie.match(reg)) {
				return unescape(arr[2]);
			} else {
				return null;
			}
		},
		//
		deleteCookie (name) {
			var exp = new Date();
			exp.setTime(exp.getTime() - 1);
			var cval = app.getCookie(name);
			if (cval != null) {
				document.cookie = name + "=" + cval + ";expires=" + exp.toGMTString();
			}
		},
		//----------------------------------------------------------------------
		invoke (func, args, success, error, hideLoading) {
			var data = {};
			for (var i = 0; i < args.length; i++) {
				data["arg" + i] = JSON.stringify(args[i]);
			}
			console.log(">>>invoke:", func, args);
			if (hideLoading == null) {
				var timeoutId = setTimeout(function () {
					app.showLoading('正在加载');
				}, 1000);
			}//
			ajax().post(app.serverAddr + '/p/api/invoke/' + func, data).always(function (response, xhr) {
				clearTimeout(timeoutId);
				app.hideLoading();
				//
				if (xhr.status != 200) {
					app.toast("网络连接失败，请检查网络");
				} else {
					var ss = response.split("\n");
					var ret = ss[0];
					var exception = "";
					for (var i = 1; i < ss.length; i++) {
						exception += ss[i];
					}
					if (exception != null && exception != '') {
						var qq = exception.split(",");
						var errorMessage = [];
						for (var i = 2; i < qq.length; i++) {
							errorMessage.push(qq[i]);
						}
						var errorString = errorMessage.join(",");
						console.log("<<<invoke:", func, errorString);
						if (app.invokeErrorHandler) {
							app.invokeErrorHandler(qq[1], errorString)
						}
						if (error) {
							error(qq[1], errorString);
						}
						app.toast("" + errorString);
					} else {
						var t = null;
						if (ret != '') {
							t = JSON.parse(ret);
						}
						console.log("<<<invoke:", func, t);
						if (success) {
							success(t)
						}
					}
				}
			})
		}
		//
	}
}

